@@ -13,6 +13,7 @@ from pyg_base._eq import eq, in_
 from pyg_base._file import read_csv
 from pyg_base._getitem import getitem, callitem, callattr
 from pyg_base._inspect import getargspec, getargs, getcallargs, getcallarg, call_with_callargs, argspec_defaults, argspec_required, argspec_update, argspec_add, kwargs2args
+from pyg_base._interp import interpolate
 from pyg_base._logger import logger, get_logger
 from pyg_base._loop import loop, loops, len0, pd2np, shape, loop_all, skip_if_data_pd, skip_if_data_pd_or_np, grab_parameter_from_dict
 from pyg_base._named_dict import named_dict
@@ -23,6 +24,7 @@ from pyg_base._perdictable import join, perdictable
 from pyg_base._reducer import reducer, reducing
 from pyg_base._roll import df_roll_off
 from pyg_base._sort import sort, cmp, Cmp
+from pyg_base._tenor import years_between, years_to_maturity
 from pyg_base._tree import is_tree, tree_to_table
 from pyg_base._tree_repr import tree_repr
 from pyg_base._txt import alphabet, ALPHABET, f12, as_ascii, replace, relabel_lower, lower, upper, proper, strip, split, capitalize, common_prefix, deprefix
